# DegTrig

A PyPi module providing all of the trigonometric functions that deal in degrees. No more math and numpy radians confusion!

![Generic badge](https://img.shields.io/badge/version-0.0.1-green.svg)

## How does it work?

**Use import DegTrig to get access to the convert functions:**

```python
from degtrig import \*
```
and then use the functions:
```python
sin(30)
cosh(1)
asin(1/2)
atanh(9)
```

## Why DegTrig

`math` provides trigonometric functions however the normal functions use radians while the hyperbolic functions use degrees. It's all a little too much to remember! DegTrig provides the answer to this problem by unifying the functions so that they all use degrees (the better unit of rotation).

## Installation

On bash:
```bash
$ pip install DegTrig
```

On windows:
```
python -m pip install DegTrig
```

## Usage

* [Contributing](#Contributing)


## Contributing

1. Fork it ( https://github.com/ )
2. Create your feature branch (`git checkout -b my-new-feature`)
3. Commit your changes (`git commit -am 'Add some feature'`)
4. Push to the branch (`git push origin my-new-feature`)
5. Make sure that the script does not have errors or warnings
6. Create a new Pull Request

## License

This tool is open source under the [MIT License](https://opensource.org/licenses/MIT) terms.

[[Back To Top]](#DegTrig)